@@ -1,8 +1,8 @@
-use crate::errors::Error;
+use crate::YggdrasilError;
 
 pub struct ASTBuilder {
     pub input: String,
-    pub error: Vec<Error>,
+    pub error: Vec<YggdrasilError>,
 }
 
 impl Default for ASTBuilder {
