@@ -1,6 +1,7 @@
 mod builder;
 mod cst_node;
 mod text_store;
+mod literal;
 
 #[cfg(feature = "lsp")]
 mod text_index;
@@ -14,3 +15,4 @@ pub use self::{builder::ASTBuilder, cst_node::CSTNode, text_store::TextStore};
 pub use url::Url;
 pub use ropey::Rope;
 pub use dashmap::{DashMap, DashSet};
+pub use self::literal::{MaybeRanged, Literal};
\ No newline at end of file
